import * as gcp from '@cdktf/provider-google';
import { Construct, ConstructOptions } from 'constructs';
import { DockerVolumes } from './gitlab-runner-interfaces';
/**
 * @stability stable
 */
export interface GitlabRunnerAutoscalingProps extends ConstructOptions {
    /**
     * Google Cloud Provider.
     *
     * @stability stable
     */
    readonly provider: gcp.GoogleProvider;
    /**
     * Gitlab token.
     *
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN' });
     */
    readonly gitlabToken: string;
    /**
     * Runner default EC2 instance type.
     *
     * @default -
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', instanceType: 't3.small' });
     */
    readonly machineType?: string;
    /**
     * VPC for the Gitlab Runner .
     *
     * @default - A new VPC will be created.
     * @stability stable
     * @example
     *
     * const computeNetwork = new gcp.ComputeNetwork(this, 'Network', {
     *   name: 'cdktf-gitlabrunner-network',
     * });
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', computeNetwork: computeNetwork });
     */
    readonly computeNetwork?: gcp.DataGoogleComputeNetwork;
    /**
     * Desired capacity limit for autoscaling group.
     *
     * @default - minCapacity, and leave unchanged during deployment
     * @stability stable
     * @example
     *
     * new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN', desiredCapacity: 2 });
     */
    readonly desiredCapacity?: number;
    /**
     * tags for the runner.
     *
     * @default - ['runner', 'gitlab', 'awscdk']
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * Gitlab Runner register url .
     *
     * @default - https://gitlab.com/ , The trailing slash is mandatory.
     * @stability stable
     * @example
     *
     * const runner = new GitlabRunnerAutoscaling(stack, 'runner', { gitlabToken: 'GITLAB_TOKEN',gitlabUrl: 'https://gitlab.com/'});
     */
    readonly gitlabUrl?: string;
    /**
     * add another Gitlab Container Runner Docker Volumes Path at job runner runtime.
     *
     * more detail see https://docs.gitlab.com/runner/configuration/advanced-configuration.html#the-runnersdocker-section
     *
     * @default - already mount "/var/run/docker.sock:/var/run/docker.sock"
     * @stability stable
     * @example
     *
     * dockerVolumes: [
     *   {
     *     hostPath: '/tmp/cache',
     *     containerPath: '/tmp/cache',
     *   },
     * ],
     */
    readonly dockerVolumes?: DockerVolumes[];
    /**
     * Gitlab Runner instance Disk size.
     *
     * @default - 60 GB.
     * @stability stable
     */
    readonly defaultDiskSizeGb?: number;
    /**
     * The Service Account to be used by the Gitlab Runner.
     *
     * @stability stable
     */
    readonly serviceAccount?: gcp.ComputeInstanceTemplateServiceAccount;
    /**
     * Firewall rules for the Gitlab Runner.
     *
     * @stability stable
     */
    readonly networkTags?: string[];
    /**
     * If true, create preemptible VM instances intended to reduce cost.
     *
     * Note, the MIG will recreate pre-empted instnaces.
     * See https://cloud.google.com/compute/docs/instances/preemptible
     *
     * @stability stable
     * @deafult - true
     */
    readonly preemptible?: boolean;
    /**
     * If true, automatically restart instances on maintenance events.
     *
     * See https://cloud.google.com/compute/docs/instances/live-migration#autorestart
     *
     * @default - false
     * @stability stable
     */
    readonly automaticRestart?: boolean;
    /**
     * gitlab runner run task concurrent at the same time.
     *
     * @default - 1
     * @stability stable
     */
    readonly concurrent?: number;
    /**
     * The source URL used to install the gitlab-runner onto the VM host os.
     *
     * Passed to curl via cloud-config runcmd.
     *
     * @default - "https://gitlab-runner-downloads.s3.amazonaws.com/latest/binaries/gitlab-runner-linux-amd64"
     * @stability stable
     */
    readonly downloadGitlabRunnerBinaryUrl?: string;
}
/**
 * @stability stable
 */
export declare class GitlabRunnerAutoscaling extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: GitlabRunnerAutoscalingProps);
    private dockerVolumesList;
    /**
     * @returns Array.
     * @stability stable
     */
    createMetadataStartupScript(props: GitlabRunnerAutoscalingProps): string[];
    private createShutdwonScript;
}
